@@ -26,9 +26,6 @@ class Element(Generic[T]):
 
     The generic type is bound by subclasses to indicate their return
     type when called.
-    # TODO: enum
-    # TODO: const
-    # TODO: composition?
     """
 
     # This is how many options there are!
@@ -39,10 +36,14 @@ class Element(Generic[T]):
         # Bad name to match JSONSchema keywords.
         # pylint: disable=redefined-builtin
         default: Maybe[Any] = NotPassed(),
+        const: Maybe[Any] = NotPassed(),
+        enum: Maybe[List[Any]] = NotPassed(),
         items: Maybe[Union["Element", List["Element"]]] = NotPassed(),
         additionalItems: Union["Element", bool] = True,
         minItems: Maybe[int] = NotPassed(),
         maxItems: Maybe[int] = NotPassed(),
+        uniqueItems: bool = False,
+        contains: Maybe["Element"] = NotPassed(),
         minimum: Maybe[Numeric] = NotPassed(),
         maximum: Maybe[Numeric] = NotPassed(),
         exclusiveMinimum: Maybe[Numeric] = NotPassed(),
@@ -56,12 +57,22 @@ class Element(Generic[T]):
         properties: Maybe[Dict[str, "_Property"]] = NotPassed(),
         patternProperties: Maybe[Dict[str, "Element"]] = NotPassed(),
         additionalProperties: Union["Element", bool] = True,
+        minProperties: Maybe[int] = NotPassed(),
+        maxProperties: Maybe[int] = NotPassed(),
+        propertyNames: Maybe["Element"] = NotPassed(),
+        dependencies: Maybe[
+            Dict[str, Union[List[str], "Element"]]
+        ] = NotPassed(),
     ):
         self.default = default
+        self.const = const
+        self.enum = enum
         self.items = items
         self.additionalItems = additionalItems
         self.minItems = minItems
         self.maxItems = maxItems
+        self.uniqueItems = uniqueItems
+        self.contains = contains
         self.minimum = minimum
         self.maximum = maximum
         self.exclusiveMinimum = exclusiveMinimum
@@ -83,6 +94,10 @@ class Element(Generic[T]):
                     )
         self.patternProperties = patternProperties
         self.additionalProperties = additionalProperties
+        self.minProperties = minProperties
+        self.maxProperties = maxProperties
+        self.propertyNames = propertyNames
+        self.dependencies = dependencies
 
     def __repr__(self):
         """Dynamically construct the repr to match value instantiation."""
