@@ -1,3 +1,5 @@
+from typing import Any, List
+
 from statham.dsl.elements.base import Element
 from statham.dsl.constants import Maybe, NotPassed
 from statham.dsl.validation import InstanceOf
@@ -13,6 +15,8 @@ class String(Element[str]):
         self,
         *,
         default: Maybe[str] = NotPassed(),
+        const: Maybe[Any] = NotPassed(),
+        enum: Maybe[List[Any]] = NotPassed(),
         # Bad name to match JSONSchema keywords.
         # pylint: disable=redefined-builtin
         format: Maybe[str] = NotPassed(),
@@ -22,6 +26,8 @@ class String(Element[str]):
         maxLength: Maybe[int] = NotPassed(),
     ):
         self.default = default
+        self.const = const
+        self.enum = enum
         self.format = format
         self.pattern = pattern
         self.minLength = minLength
